@@ -1,16 +1,13 @@
-require 'rubygems'
 require 'bundler/setup'
 require 'minitest/autorun'
+require 'minitest/rg'
+require 'pry'
 
 $VERBOSE = true # enable ruby warnings
 
-begin
-  require 'mocha/setup'
-rescue LoadError
-  require 'mocha'
-end
+require 'mocha/minitest'
 
-class Minitest::Unit::TestCase
+class Minitest::Test
   private
     # Tests to see that two times are within the given distance,
     # in seconds, from each other.
@@ -32,7 +29,7 @@ class Minitest::Unit::TestCase
       Time.at(time.to_i).to_datetime.offset
     end
 
-    TIMEZONES = ["Europe/Paris", "UTC", "America/Chicago"]
+    TIMEZONES = ["Pacific/Midway", "Europe/Paris", "UTC", "America/Chicago"]
 
     def each_timezone
       old_tz = ENV["TZ"]
@@ -55,4 +52,8 @@ class Minitest::Unit::TestCase
       assert_in_delta dt1.to_time.to_f, dt2.to_time.to_f, 0.01, "Failed for timezone: #{ENV['TZ']}: #{dt1.to_s} not equal to #{dt2.to_s}"
     end
 
+    def jruby?
+      RUBY_PLATFORM == "java"
+    end
+
 end
