@@ -181,7 +181,7 @@ class TestTimeStackItem < Minitest::Test
     t = Time.local(2009, 10, 1, 0, 0, 30)
     tsi = Timecop::TimeStackItem.new(:freeze, t)
 
-    assert_equal nil, tsi.send(:travel_offset)
+    assert_nil tsi.send(:travel_offset)
   end
 
   def test_timezones
@@ -206,7 +206,7 @@ class TestTimeStackItem < Minitest::Test
     time = Time.zone.local(2013,1,3)
 
     Timecop.freeze(time) do
-      assert_equal time.to_date, Time.now.to_date
+      assert_equal time.to_date, Time.zone.now.to_date
     end
   end
 
